@@ -17,6 +17,11 @@ def matmul(a: Numeric, b: Numeric, tr_a: bool = False, tr_b: bool = False):
     return tf.matmul(a, b, transpose_a=tr_a, transpose_b=tr_b)
 
 
+@dispatch
+def einsum(equation: str, *elements: Numeric):
+    return tf.einsum(equation, *elements)
+
+
 @dispatch
 def transpose(a: Numeric, perm: Optional[Union[tuple, list]] = None):
     # Correctly handle special cases.
