@@ -152,6 +152,11 @@ def log(a: Numeric):
     return torch.log(a)
 
 
+@dispatch
+def log1p(a: Numeric):
+    return torch.log1p(a)
+
+
 @dispatch
 def sin(a: Numeric):
     return torch.sin(a)
@@ -197,6 +202,11 @@ def erf(a: Numeric):
     return torch.erf(a)
 
 
+@dispatch
+def softplus(a: TorchNumeric):
+    return torch.nn.functional.softplus(a)
+
+
 @dispatch
 def add(a: Numeric, b: Numeric):
     return a + b
