@@ -65,57 +65,71 @@ def test_create_random_state(dtype):
 
 
 @pytest.mark.parametrize(
-    "f, dtype_transform",
+    "f, dtype_transform, just_single_arg",
     [
-        (B.rand, lambda x: x),
-        (B.randn, lambda x: x),
-        (lambda *args: B.randint(*args, lower=0, upper=10), B.dtype_int),
+        (B.rand, lambda x: x, False),
+        (B.randn, lambda x: x, False),
+        (lambda *args: B.randint(*args, lower=0, upper=10), B.dtype_int, False),
+        (B.randperm, B.dtype_int, True),
     ],
 )
-def test_random_generators(f, dtype_transform, check_lazy_shapes):
+def test_random_generators(f, dtype_transform, just_single_arg, check_lazy_shapes):
     # Test without specifying data type.
-    assert B.dtype(f()) is dtype_transform(B.default_dtype)
-    assert B.shape(f()) == ()
+    if not just_single_arg:
+        assert B.dtype(f()) is dtype_transform(B.default_dtype)
+        assert B.shape(f()) == ()
     assert B.dtype(f(2)) is dtype_transform(B.default_dtype)
-    approx(B.shape(f(2)), (2,))
-    assert B.dtype(f(2, 3)) is dtype_transform(B.default_dtype)
-    assert B.shape(f(2, 3)) == (2, 3)
+    assert B.shape(f(2)) == (2,)
+    if not just_single_arg:
+        assert B.dtype(f(2, 3)) is dtype_transform(B.default_dtype)
+        assert B.shape(f(2, 3)) == (2, 3)
 
     # Test with specifying data type.
     for t in [np.float32, tf.float32, torch.float32, jnp.float32]:
         state = B.create_random_state(t, 0)
 
         # Test direct specification.
-        assert B.dtype(f(t)) is dtype_transform(t)
-        assert B.shape(f(t)) == ()
+        if not just_single_arg:
+            assert B.dtype(f(t)) is dtype_transform(t)
+            assert B.shape(f(t)) == ()
         assert B.dtype(f(t, 2)) is dtype_transform(t)
         assert B.shape(f(t, 2)) == (2,)
-        assert B.dtype(f(t, 2, 3)) is dtype_transform(t)
-        assert B.shape(f(t, 2, 3)) == (2, 3)
+        if not just_single_arg:
+            assert B.dtype(f(t, 2, 3)) is dtype_transform(t)
+            assert B.shape(f(t, 2, 3)) == (2, 3)
 
-        assert isinstance(f(state, t)[0], B.RandomState)
-        assert B.dtype(f(state, t)[1]) is dtype_transform(t)
-        assert B.shape(f(state, t)[1]) == ()
+        # Test state specification.
+        if not just_single_arg:
+            assert isinstance(f(state, t)[0], B.RandomState)
+            assert B.dtype(f(state, t)[1]) is dtype_transform(t)
+            assert B.shape(f(state, t)[1]) == ()
+        assert isinstance(f(state, t, 2)[0], B.RandomState)
         assert B.dtype(f(state, t, 2)[1]) is dtype_transform(t)
         assert B.shape(f(state, t, 2)[1]) == (2,)
-        assert B.dtype(f(state, t, 2, 3)[1]) is dtype_transform(t)
-        assert B.shape(f(state, t, 2, 3)[1]) == (2, 3)
+        if not just_single_arg:
+            assert isinstance(f(state, t, 2, 3)[0], B.RandomState)
+            assert B.dtype(f(state, t, 2, 3)[1]) is dtype_transform(t)
+            assert B.shape(f(state, t, 2, 3)[1]) == (2, 3)
 
-        # Test reference specification.
-        assert B.dtype(f(f(t))) is dtype_transform(t)
-        assert B.shape(f(f())) == ()
-        assert B.dtype(f(f(t, 2))) is dtype_transform(t)
-        assert B.shape(f(f(t, 2))) == (2,)
-        assert B.dtype(f(f(t, 2, 3))) is dtype_transform(t)
-        assert B.shape(f(f(t, 2, 3))) == (2, 3)
+        if not just_single_arg:
+            # Test reference specification.
+            assert B.dtype(f(f(t))) is dtype_transform(t)
+            assert B.shape(f(f())) == ()
+            assert B.dtype(f(f(t, 2))) is dtype_transform(t)
+            assert B.shape(f(f(t, 2))) == (2,)
+            assert B.dtype(f(f(t, 2, 3))) is dtype_transform(t)
+            assert B.shape(f(f(t, 2, 3))) == (2, 3)
 
-        # Must stay within the framework now.
-        assert isinstance(f(state, f(t))[0], B.RandomState)
-        assert B.dtype(f(state, f(t))[1]) is dtype_transform(t)
-        assert B.dtype(f(state, f(t, 2))[1]) is dtype_transform(t)
-        assert B.shape(f(state, f(t, 2))[1]) == (2,)
-        assert B.dtype(f(state, f(t, 2, 3))[1]) is dtype_transform(t)
-        assert B.shape(f(state, f(t, 2, 3))[1]) == (2, 3)
+            # Test state and reference specification.
+            assert isinstance(f(state, f(t))[0], B.RandomState)
+            assert B.dtype(f(state, f(t))[1]) is dtype_transform(t)
+            assert B.shape(f(state, f(t))[1]) == ()
+            assert isinstance(f(state, f(t, 2))[0], B.RandomState)
+            assert B.dtype(f(state, f(t, 2))[1]) is dtype_transform(t)
+            assert B.shape(f(state, f(t, 2))[1]) == (2,)
+            assert isinstance(f(state, f(t, 2, 3))[0], B.RandomState)
+            assert B.dtype(f(state, f(t, 2, 3))[1]) is dtype_transform(t)
+            assert B.shape(f(state, f(t, 2, 3))[1]) == (2, 3)
 
 
 def test_randint_bounds(check_lazy_shapes):
